==> haskell-exact-pi-0.5.0.2-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 exact-pi
version:              0.5.0.2
visibility:           public
id:                   exact-pi-0.5.0.2-7PrG4SnNF7hCiGB0T2mNia
key:                  exact-pi-0.5.0.2-7PrG4SnNF7hCiGB0T2mNia
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  40ca75688bb4e965f8030912b159611a
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.2.8/site-local/exact-pi-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/exact-pi-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-exact-pi
hs-libraries:         HSexact-pi-0.5.0.2-7PrG4SnNF7hCiGB0T2mNia
depends:
    base-4.16.4.0 numtype-dk-0.5.0.3-89eY94N4xeAfNXJQwHHE5

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exact-pi-0.5.0.2-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 exact-pi
version:              0.5.0.2
visibility:           public
id:                   exact-pi-0.5.0.2-AICxDJsJ1TO14KoYQWqF8v
key:                  exact-pi-0.5.0.2-AICxDJsJ1TO14KoYQWqF8v
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  c46e40f95683352754209540c1cae9c1
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.2.8/site-local/exact-pi-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/exact-pi-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-exact-pi
hs-libraries:         HSexact-pi-0.5.0.2-AICxDJsJ1TO14KoYQWqF8v
depends:
    base-4.16.4.0 numtype-dk-0.5.0.3-89eY94N4xeAfNXJQwHHE5

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
